BTreeSet

Struct BTreeSet 

pub struct BTreeSet<'store, T> { /* private fields */ }
A copyable, immutable b-tree set, which doesn’t drop its contents.

Implementations

Source

impl<'store, T> BTreeSet<'store, T>

pub fn len(&self) -> usize

Returns the number of elements in the set.

pub fn is_empty(&self) -> bool

Returns true if the set contains no elements.

pub fn first(&self) -> Option<&T>

The first value in the set, or None if empty.

pub fn last(&self) -> Option<&T>

The last value in the set, or None if empty.

pub fn contains<U: Ord>(&self, value: &U) -> bool
where T: Borrow<U>,

Returns true if the set contains a value.

pub fn get<U: Ord>(&self, value: &U) -> Option<&T>
where T: Borrow<U>,

Returns a reference to the equivalent value in the set, if any.

This is (only) useful when U is a different type than T.

pub fn validate(&self)
where T: Debug + Ord,

Validates the set, panicing if it is invalid. Specifically, we check that the number of entries in each node is within the b-tree invariant bounds, and that the elements are in order.

Ideally, this should always be a no-op.

pub fn print(&self, f: &mut Formatter<'_>) -> Result
where T: Debug,

Prints the b-tree in ascii

pub fn iter(&self) -> Iter<'_, T>

Returns an iterator over the set.

pub fn range<U: Ord>(&self, bounds: impl RangeBounds<U>) -> Range<'_, T>
where T: Borrow<U>,

Returns an iterator over the set within the given bounds