pub struct BTreeSet<'store, T> { /* private fields */ }Expand description
A copyable, immutable b-tree set, which doesn’t drop its contents.
Implementations
Sourceimpl<'store, T> BTreeSet<'store, T>
impl<'store, T> BTreeSet<'store, T>
Sourcepub fn contains<U: Ord>(&self, value: &U) -> boolwhere
T: Borrow<U>,
pub fn contains<U: Ord>(&self, value: &U) -> boolwhere
T: Borrow<U>,
Returns true if the set contains a value.
Sourcepub fn get<U: Ord>(&self, value: &U) -> Option<&T>where
T: Borrow<U>,
pub fn get<U: Ord>(&self, value: &U) -> Option<&T>where
T: Borrow<U>,
Returns a reference to the equivalent value in the set, if any.
This is (only) useful when U is a different type than T.